summaryrefslogtreecommitdiffstats
path: root/src/import/chips/common/utils
diff options
context:
space:
mode:
Diffstat (limited to 'src/import/chips/common/utils')
-rw-r--r--src/import/chips/common/utils/imageProcs/common_ringId.H4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/import/chips/common/utils/imageProcs/common_ringId.H b/src/import/chips/common/utils/imageProcs/common_ringId.H
index f61cc397..60bc4452 100644
--- a/src/import/chips/common/utils/imageProcs/common_ringId.H
+++ b/src/import/chips/common/utils/imageProcs/common_ringId.H
@@ -134,13 +134,14 @@ enum TorMagicNum
//
// Chip types and List to represent p9n, p9c, cen (centaur)
// NB! There's a matching CHIP_TYPE_LIST definition in common_ringId.C
//
enum ChipType
{
CT_P9N, // ==P9 for now
CT_P9C, // ==P9 for now
+ CT_P9A,
CT_CEN,
NUM_CHIP_TYPES
};
@@ -155,6 +156,7 @@ static const ChipTypeList_t CHIP_TYPE_LIST[] =
{
{"p9n", CT_P9N},
{"p9c", CT_P9C},
+ {"p9a", CT_P9A},
{"cen", CT_CEN},
};
OpenPOWER on IntegriCloud
@@ -134,13 +134,14 @@ enum TorMagicNum
//
-// Chip types and List to represent p9n, p9c, cen (centaur)
+// Chip types and List to represent p9n, p9c, p9a, cen (centaur)
// NB! There's a matching CHIP_TYPE_LIST definition in common_ringId.C
//